<?php

/**
 * @file
 * Drush integration for iubenda.
 */

/**
 * The Iubenda PHP class URI.
 */
define('IUBENDA_DOWNLOAD_URI', 'https://github.com/iubenda/iubenda-cookie-class/archive/refs/tags/v4.1.8.zip');
define('IUBENDA_MODULE_NAME', 'iubenda_integration');
define('IUBENDA_LIB_DIR', 'iubenda-cookie-class-4.1.8');

/**
 * Implements hook_drush_command().
 *
 * In this hook, you specify which commands your
 * drush module makes available, what it does and
 * description.
 *
 * Notice how this structure closely resembles how
 * you define menu hooks.
 *
 * See `drush topic docs-commands` for a list of recognized keys.
 */
function iubenda_integration_drush_command() {
  // The key in the $items array is the name of the command.
  return [
    'iubenda-php-class' => [
      'callback' => 'drush_iubenda_php_class',
      'description' => dt('Download and install the Iubenda PHP class.'),
      // No bootstrap.
      'bootstrap' => DRUSH_BOOTSTRAP_DRUSH,
      'arguments' => [
        'path' => dt("Optional. A path where to install the Iubenda PHP class."
          . "\nIf omitted Drush will use the default location."),
      ],
      'aliases' => ['ipc'],
    ],
  ];
}

/**
 * Implements hook_drush_help().
 *
 * This function is called whenever a drush user calls
 * 'drush help <name-of-your-command>'
 */
function iubenda_integration_drush_help($section) {
  switch ($section) {
    case 'drush:iubenda-php-class':
      return dt("Download and install the Iubenda PHP class from"
        . "\nhttps://www.iubenda.com/it/help/posts/1045, default location"
        . "\nis sites/all/libraries.");
  }
}

/**
 * Implements drush_MODULE_pre_pm_enable().
 */
function drush_iubenda_integration_pre_pm_enable() {
  $modules = drush_get_context('PM_ENABLE_MODULES');
  if (in_array(IUBENDA_MODULE_NAME, $modules) && !drush_get_option('skip')) {
    drush_iubenda_php_class();
  }
}

/**
 * Command to download the Iubenda PHP class.
 */
function drush_iubenda_php_class() {
  $args = func_get_args();
  if (!empty($args[0])) {
    $path = $args[0];
  }
  else {
    $path = 'sites/all/libraries';
  }

  // Create the path if it does not exist.
  if (!is_dir($path)) {
    drush_op('mkdir', $path);
    drush_log(dt('Directory @path was created', array('@path' => $path)), 'notice');
  }

  // Set the directory to the download location.
  $current_dir = getcwd();
  chdir($path);

  // Download the zip archive.
  if ($filepath = drush_download_file(IUBENDA_DOWNLOAD_URI)) {

    // Remove any existing Iubenda PHP class directory.
    if (is_dir(IUBENDA_LIB_DIR)) {
      drush_delete_dir(IUBENDA_LIB_DIR, TRUE);
      drush_log(dt('The existing Iubenda PHP class was deleted from @path',
        ['@path' => $path]), 'notice');
    }

    // Decompress the zip archive.
    drush_tarball_extract($filepath);
  }

  if (is_dir(IUBENDA_LIB_DIR)) {
    drush_log(dt('Iubenda PHP class has been installed in @path',
      ['@path' => $path]), 'success');
  }
  else {
    drush_log(dt('Drush was unable to install the Iubenda PHP class to @path',
      ['@path' => $path]), 'error');
  }

  // Set working directory back to the previous working directory.
  chdir($current_dir);
}
