<?php

/**
 * @file
 * Code for Iubenda Integration administration.
 */

/**
 * Iubenda Integration Privacy Policy settings form.
 */
function iubenda_integration_privacy_policy_settings_form($form, &$form_state) {
  
  $form['settings'] = [
    '#type' => 'vertical_tabs',
  ];
  
  $form['settings']['iubenda'] = [
    '#title' => t('Iubenda'),
    '#type' => 'fieldset',
    '#collapsible' => TRUE,
  ];
  
  $form['settings']['iubenda']['iubenda_integration_policy_code'] = [
    '#title' => t('Iubenda Privacy Policy code'),
    '#type' => 'textfield',
    '#description' => t('Insert the privacy policy code generated by Iubenda for your website.'),
    '#default_value' => variable_get('iubenda_integration_policy_code', ''),
    '#required' => TRUE,
    '#size' => 10,
  ];
  
  $form['settings']['iubenda']['iubenda_integration_style'] = [
    '#title' => t('Style'),
    '#type' => 'radios',
    '#options' => [
      'iubenda-nostyle' => t('No style'),
      'iubenda-white' => t('White'),
      'iubenda-black' => t('Black'),
    ],
    '#default_value' => variable_get('iubenda_integration_style', 'iubenda-nostyle'),
    '#required' => TRUE,
  ];
  
  $form['settings']['iubenda']['iubenda_integration_legal_only'] = [
    '#title' => t('Show legal only'),
    '#type' => 'checkbox',
    '#default_value' => variable_get('iubenda_integration_legal_only', FALSE),
  ];
  
  $form['settings']['iubenda']['iubenda_integration_show_brand'] = [
    '#title' => t('Show brand'),
    '#type' => 'checkbox',
    '#default_value' => variable_get('iubenda_integration_show_brand', FALSE),
  ];
  
  $form['settings']['form'] = [
    '#title' => t('Form'),
    '#type' => 'fieldset',
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  ];
  
  $form['settings']['form']['iubenda_integration_form_element_type'] = [
    '#title' => t('Form element type'),
    '#type' => 'select',
    '#options' => [
      'checkbox' => t('Checkbox'),
      'radio' => t('Radio'),
    ],
    '#default_value' => variable_get('iubenda_integration_form_element_type', 'checkbox'),
  ];
  
  $form['settings']['form']['iubenda_integration_forms'] = [
    '#title' => t('Privacy Policy Forms'),
    '#description' => t('Insert here, one per line, a list of form ids for which Iubenda Privacy Policy have to be displayed.'),
    '#type' => 'textarea',
    '#default_value' => variable_get('iubenda_integration_forms', ''),
  ];
  
  $form['settings']['form']['text'] = [
    '#title' => t('Text'),
    '#type' => 'fieldset',
  ];
  
  $form['settings']['form']['text']['iubenda_integration_pretext'] = [
    '#title' => t('Pre-Text'),
    '#description' => t('Insert text of the Privacy Policy line have to precede Iubenda link'),
    '#type' => 'textarea',
    '#default_value' => variable_get('iubenda_integration_pretext', ''),
  ];
  
  $form['settings']['form']['text']['iubenda_integration_text'] = [
    '#title' => t('Link Text'),
    '#description' => t('Insert text that will be displayed as link'),
    '#type' => 'textfield',
    '#default_value' => variable_get('iubenda_integration_text', t('Privacy Policy')),
    '#required' => TRUE,
  ];
  
  $form['settings']['form']['text']['iubenda_integration_posttext'] = [
    '#title' => t('Post-Text'),
    '#description' => t('Insert text of the Privacy Policy line have to follow Iubenda link'),
    '#type' => 'textarea',
    '#default_value' => variable_get('iubenda_integration_posttext', ''),
  ];
  
  $form['settings']['block'] = [
    '#title' => t('Block'),
    '#type' => 'fieldset',
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  ];
  
  $form['settings']['block']['iubenda_integration_block_pretext'] = [
    '#title' => t('Pre-Text'),
    '#description' => t('Insert text of the Privacy Policy line have to precede Iubenda link'),
    '#type' => 'textarea',
    '#default_value' => variable_get('iubenda_integration_block_pretext', ''),
  ];
  
  $form['settings']['block']['iubenda_integration_block_text'] = [
    '#title' => t('Link Text'),
    '#description' => t('Insert text that will be displayed as link'),
    '#type' => 'textfield',
    '#default_value' => variable_get('iubenda_integration_block_text', t('Privacy Policy')),
    '#required' => TRUE,
  ];
  
  $form['settings']['block']['iubenda_integration_block_posttext'] = [
    '#title' => t('Post-Text'),
    '#description' => t('Insert text of the Privacy Policy line have to follow Iubenda link'),
    '#type' => 'textarea',
    '#default_value' => variable_get('iubenda_integration_block_posttext', ''),
  ];
  
  return system_settings_form($form);
}

/**
 * Iubenda Integration Cookie Policy settings form.
 */
function iubenda_integration_cookie_policy_settings_form($form, &$form_state) {
  $form['#form_id'] = __FUNCTION__;
  $form['#prefix'] = '<div id="iubenda_integration_cookie_policy_wrapper">';
  $form['#suffix'] = '</div>';
  
  $default_enabled = variable_get('iubenda_integration_cookie_policy_enabled', FALSE);
  $enabled = isset($form_state['values']['iubenda_integration_cookie_policy_enabled']) ? $form_state['values']['iubenda_integration_cookie_policy_enabled'] : $default_enabled;
  
  $form['iubenda_integration_cookie_policy_enabled'] = [
    '#title' => t('Enable EU Cookie Policy'),
    '#type' => 'checkbox',
    '#default_value' => $enabled,
    '#ajax' => [
      'wrapper' => 'iubenda_integration_cookie_policy_wrapper',
      'callback' => 'iubenda_integration_cookie_policy_ajax_callback',
    ],
  ];
  
  $settings = variable_get('iubenda_integration_cookie_policy', []);
  $form['iubenda_integration_cookie_policy'] = [
    '#tree' => TRUE,
    '#access' => $enabled,
  ];
  
  $form['iubenda_integration_cookie_policy']['required_parameters'] = [
    '#markup' => '<h2>1. ' . t('Required parameters') . '</h2>',
  ];
  
  $form['iubenda_integration_cookie_policy']['siteId'] = [
    '#title' => t('Site ID'),
    '#type' => 'textfield',
    '#required' => TRUE,
    '#size' => 10,
    '#default_value' => !empty($settings['siteId']) ? $settings['siteId'] : NULL,
    '#description' => t('Id of the site (note: this ID is used to share the preferences of various cookie policies in multiple languages that are however connected to the same site/app)'),
  ];
  
  $form['iubenda_integration_cookie_policy']['cookiePolicyId'] = [
    '#title' => t('Cookie Policy ID'),
    '#type' => 'textfield',
    '#required' => TRUE,
    '#size' => 10,
    '#default_value' => !empty($settings['cookiePolicyId']) ? $settings['cookiePolicyId'] : NULL,
    '#description' => t('Id of your cookie policy'),
  ];
  
  $form['iubenda_integration_cookie_policy']['compliance_settings'] = [
    '#markup' => '<h2>2. ' . t('Compliance settings') . '</h2>',
  ];
  
  $form['iubenda_integration_cookie_policy']['countryDetection'] = [
    '#title' => t('Country detection'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['countryDetection']) ? $settings['countryDetection'] : FALSE,
    '#description' => t('Allows you to automatically detect the user country.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['gdpr'] = [
    '#markup' => '<h3>2.1 ' . t('GDPR') . '</h3>',
  ];
  
  $form['iubenda_integration_cookie_policy']['enableGdpr'] = [
    '#title' => t('Enable GDPR'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['enableGdpr']) ? $settings['enableGdpr'] : TRUE,
    '#description' => t('If true, you’ll enable/make available the GDPR functionality in the Cookie Solution (without actually applying it).'),
  ];
  
  $form['iubenda_integration_cookie_policy']['gdprAppliesGlobally'] = [
    '#title' => t('GDPR applies globally'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['gdprAppliesGlobally']) ? $settings['gdprAppliesGlobally'] : TRUE,
    '#description' => t('If true, you’ll apply GDPR protections to all users. Set this parameter to false and countryDetection:true to request consent to EU users only. Remember that if you’re based in the EU you must apply the GDPR also to users based outside of the EU.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['gdprApplies'] = [
    '#title' => t('GDPR Applies'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['gdprApplies']) ? $settings['gdprApplies'] : TRUE,
    '#description' => t(' If false, you won’t apply GDPR protections to the current user and he will not be shown the cookie banner. If you’ve set countryDetection:false, you should set gdprApplies:false on all page views where the consent is not being requested.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['consent'] = [
    '#markup' => '<h4>' . t('Consent on continued browsing, scroll and page interaction') . '</h4>',
  ];
  
  $form['iubenda_integration_cookie_policy']['consentOnContinuedBrowsing'] = [
    '#title' => t('Consent on continued browsing'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['consentOnContinuedBrowsing']) ? $settings['consentOnContinuedBrowsing'] : TRUE,
    '#description' => t('If set to false, consentOnScroll, consentOnDocument and consentOnLinkAndButton are set to false, and consentOnElement is set to no element. This way you only accept explicit consent, while consent on scroll and page interaction is not given.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['consentOnScroll'] = [
    '#title' => t('Consent on scroll'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['consentOnScroll']) ? $settings['consentOnScroll'] : TRUE,
    '#description' => t('You can set this parameter to false to avoid the registration of the user’s consent when the page is scrolled.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['consentOnHorizontalScroll'] = [
    '#title' => t('Consent on horizontal scroll'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['consentOnHorizontalScroll']) ? $settings['consentOnHorizontalScroll'] : FALSE,
    '#description' => t('By setting this parameter to true, the consent is given even in cases of horizontal scrolling.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['consentOnScrollOnElement'] = [
    '#title' => t('Consent on scroll on element'),
    '#type' => 'textarea',
    '#rows' => 1,
    '#default_value' => isset($settings['consentOnScrollOnElement']) ? $settings['consentOnScrollOnElement'] : NULL,
    '#description' => t('The scrolling event is observed on the element passed as a parameter (including selectors like classes and ids).'),
  ];
  
  $form['iubenda_integration_cookie_policy']['consentOnLinkAndButton'] = [
    '#title' => t('Consent on link and button'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['consentOnLinkAndButton']) ? $settings['consentOnLinkAndButton'] : TRUE,
    '#description' => t('The user’s consent is normally recorded also after a click on a button (button) on the page, as well as on the links (a). Set to false, the consentOnLinkAndButton parameter (formerly consentOnButton) changes the default behavior by ensuring that the consent results as “not given” in these cases.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['consentOnElement'] = [
    '#title' => t('Consent on element'),
    '#type' => 'textarea',
    '#rows' => 1,
    '#default_value' => isset($settings['consentOnElement']) ? $settings['consentOnElement'] : 'input, textarea, form',
    '#description' => t('The scrolling event is observed on the element passed as a parameter (including selectors like classes and ids).'),
  ];
  
  $form['iubenda_integration_cookie_policy']['consentOnDocument'] = [
    '#title' => t('Consent on document'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['consentOnDocument']) ? $settings['consentOnDocument'] : FALSE,
    '#description' => t('If set to true, the user’s consent will be registered if you click anywhere on the page (excluding the banner area).'),
  ];
  
  $form['iubenda_integration_cookie_policy']['category_consent'] = [
    '#markup' => '<h4>' . t('Per-category consent') . '</h4>',
  ];
  
  $form['iubenda_integration_cookie_policy']['perPurposeConsent'] = [
    '#title' => t('Per purpose consent'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['perPurposeConsent']) ? $settings['perPurposeConsent'] : FALSE,
    '#description' => t('Setting this parameter to true gives users granular control over which categories of cookies they consent to (see below). The categories are displayed along with a short description and toggle so that users can either grant or reject consent for the particular processing purpose. The categories displayed in the modal are automatically detected and passed from your iubenda cookie policy to the Cookie Solution. However, the categories displayed can also be customized by using the purposes parameter below.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['purposes'] = [
    '#title' => t('Purposes'),
    '#type' => 'textfield',
    '#default_value' => isset($settings['purposes']) ? $settings['purposes'] : NULL,
    '#description' => t('Purposes are grouped into 5 categories ([1] Strictly necessary, [2] Basic interactions & functionalities, [3] Experience enhancement, [4] Measurement, [5] Targeting & advertising), each having an id (1, 2, 3, 4, 5). By default, we use the purposes from the iubenda cookie policy connected to your configuration, but you can customize which categories to display with purposes (for example, if you use your own cookie policy).'),
  ];
  
  $form['iubenda_integration_cookie_policy']['ccpa'] = [
    '#markup' => '<h3>' . t('2.2 CCPA') . '</h3>',
  ];
  
  $form['iubenda_integration_cookie_policy']['enableCcpa'] = [
    '#title' => t('Enable CCPA'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['enableCcpa']) ? $settings['enableCcpa'] : FALSE,
    '#description' => t('If true, you’ll enable/make available the CCPA functionality in the Cookie Solution (without actually applying it).'),
  ];
  
  $form['iubenda_integration_cookie_policy']['ccpaApplies'] = [
    '#title' => t('CCPA Applies'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['ccpaApplies']) ? $settings['ccpaApplies'] : NULL,
    '#description' => t('If true, you’ll apply CCPA protections to the current user.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['ccpaNoticeDisplay'] = [
    '#title' => t('CCPA Notice display'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['ccpaNoticeDisplay']) ? $settings['ccpaNoticeDisplay'] : TRUE,
    '#description' => t('If false, you won’t display an actual banner to notify users about CCPA (effective only if GDPR doesn’t apply).'),
  ];
  
  $form['iubenda_integration_cookie_policy']['ccpaAcknowledgeOnDisplay'] = [
    '#title' => t('CCPA Acknowledge on display'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['ccpaAcknowledgeOnDisplay']) ? $settings['ccpaAcknowledgeOnDisplay'] : FALSE,
    '#description' => t('If ccpaNoticeDisplay: true, allows you to specify what constitutes acknowledgment of the notice: the simple loading of the notice (true) or the explicit interaction after the notice has loaded (false).'),
  ];
  
  $form['iubenda_integration_cookie_policy']['ccpaAcknowledgeOnLoad'] = [
    '#title' => t('CCPA Acknowledge on load'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['ccpaAcknowledgeOnLoad']) ? $settings['ccpaAcknowledgeOnLoad'] : FALSE,
    '#description' => t('If set to true and ccpaAcknowledgeOnDisplay: false, the notice is intended acknowledged at the page loading.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['ccpaLspa'] = [
    '#title' => t('CCPA LSPA'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['ccpaLspa']) ? $settings['ccpaLspa'] : NULL,
    '#description' => t('Allows you to specify whether the transaction should be performed under the Limited Service Provider Agreement (LSPA) by IAB.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['classes'] = [
    '#markup' => '<h4>' . t('Classes') . '</h4>',
    '#suffix' => '<code>iubenda-ccpa-opt-out</code> - ' . t('By adding this class to any element of the page, the click on the item triggers the opening of a dialog where the user can confirm their intention to opt-out from the sale of their personal information (“Do Not Sell My Personal Information” link).') . '<br/><br/>',
  ];
  
  $form['iubenda_integration_cookie_policy']['tcf'] = [
    '#markup' => '<h3>' . t('2.3 IAB Transparency and Consent Framework') . '</h3>',
  ];
  
  $form['iubenda_integration_cookie_policy']['enableTcf'] = [
    '#title' => t('Enable TCF'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['enableTcf']) ? $settings['enableTcf'] : FALSE,
    '#description' => t('If true, users will be able to manage their advertising tracking preferences according to the IAB Transparency and Consent Framework.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['googleAdditionalConsentMode'] = [
    '#title' => t('Google additional consent mode'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['googleAdditionalConsentMode']) ? $settings['googleAdditionalConsentMode'] : FALSE,
    '#description' => t('If set to true, you’ll be able to gather consent for Google ad partners that are not yet part of the Transparency and Consent Framework, but are on Google’s Ad Tech Providers (ATP) list.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['tcfPurposes'] = [
    '#title' => t('TFC Purposes'),
    '#type' => 'fieldset',
    '#tree' => TRUE,
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  ];
  
  $tcf_purposes = [
    "1" => t('Store and/or access information on a device'),
    "2" => t('Select basic ads'),
    "3" => t('Create a personalised ads profile'),
    "4" => t('Select personalised ads'),
    "5" => t('Create a personalised content profile'),
    "6" => t('Select personalised content'),
    "7" => t('Measure ad performance'),
    "8" => t('Measure content performance'),
    "9" => t('Apply market research to generate audience insights'),
    "10" => t('Develop and improve products'),
  ];
  $tcf_purposes_options = [
    1 => t('Enabled'),
    '' => t('Disabled'),
    "li_only" => t('Legitimate interest only'),
    "consent_only" => t('Consent only'),
    "consent_not_needed" => t('Consent not needed'),
  ];
  foreach ($tcf_purposes as $id => $tcf_purpose) {
    $form['iubenda_integration_cookie_policy']['tcfPurposes'][$id] = [
      '#title' => $tcf_purpose,
      '#type' => 'select',
      '#options' => $tcf_purposes_options,
      '#default_value' => isset($settings['tcfPurposes'][$id]) ? $settings['tcfPurposes'][$id] : 0,
    ];
  }
  
  $form['iubenda_integration_cookie_policy']['askConsentIfCMPNotFound'] = [
    '#title' => t('Ask consent if CMP is not found'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['askConsentIfCMPNotFound']) ? $settings['askConsentIfCMPNotFound'] : TRUE,
    '#description' => t('If set to true, and the IAB Framework preference is not found, the Cookie Solution will, by default, request a new consent from users that had provided consent prior to the activation of the Framework. Set this option to false to disable this default behavior.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['newConsentAtVendorListUpdate'] = [
    '#title' => t('New consent at vendor list update'),
    '#type' => 'textfield',
    '#default_value' => isset($settings['newConsentAtVendorListUpdate']) ? $settings['newConsentAtVendorListUpdate'] : NULL,
    '#description' => t('Number of days to wait to trigger a new consent request after the vendorlist.json is updated. If set to undefined, users who have already given consent will not be shown the cookie banner again, and consent for new vendors will be set to off. If set to 0 users will get prompted with a new consent request whenever the vendor list is updated.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['tcf_classes'] = [
    '#markup' => '<h4>' . t('Classes') . '</h4>',
    '#suffix' => '<code>iubenda-advertising-preferences-link</code> - ' . t('By adding this class to any element of the page, the click on the item triggers the opening of the advertising tracking settings modal (allowing users to update their TCF preferences even after closing the cookie banner).') . '<br/>
                  <code>iubenda-vendor-list-link</code> - ' . t('Add this class to any element of the page to allow users to reopen the TCF vendor list.') . '<br/>',
  ];
  
  $form['iubenda_integration_cookie_policy']['banner'] = [
    '#title' => t('Banner'),
    '#type' => 'fieldset',
    '#tree' => TRUE,
  ];
  
  $form['iubenda_integration_cookie_policy']['banner']['style_and_text'] = [
    '#markup' => '<h2>3. ' . t('Style and text') . '</h2>',
  ];
  
  $form['iubenda_integration_cookie_policy']['banner']['format_position'] = [
    '#markup' => '<h3>3.1 ' . t('Format and Position') . '</h3>',
  ];
  
  $form['iubenda_integration_cookie_policy']['banner']['position'] = [
    '#title' => t('Position'),
    '#type' => 'select',
    '#options' => [
      'top' => t('Top'),
      'bottom' => t('Bottom'),
      'float-top-left' => t('Float top left'),
      'float-top-right' => t('Float top right'),
      'float-bottom-left' => t('Float bottom left'),
      'float-bottom-right' => t('Float bottom right'),
      'float-top-center' => t('Float top center'),
      'float-bottom-center' => t('Float bottom center'),
      'float-center' => t('Float center'),
    ],
    '#default_value' => isset($settings['banner']['position']) ? $settings['banner']['position'] : 'float-top-center',
    '#description' => t('It defines the position of the cookie banner.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['banner']['backgroundOverlay'] = [
    '#title' => t('Background overlay'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['banner']['backgroundOverlay']) ? $settings['banner']['backgroundOverlay'] : FALSE,
    '#description' => t('Set this parameter to true in order to add an opaque background overlay effect to the rest of the page when the cookie banner is shown.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['banner']['theme'] = [
    '#markup' => '<h3>3.2 ' . t('Theme') . '</h3>',
  ];
  
  $form['iubenda_integration_cookie_policy']['banner']['banner_logo'] = [
    '#markup' => '<h4>' . t('Logo') . '</h4>',
  ];
  
  $form['iubenda_integration_cookie_policy']['banner']['logo'] = [
    '#title' => t('Logo'),
    '#type' => 'textarea',
    '#rows' => 1,
    '#resizable' => TRUE,
    '#default_value' => isset($settings['banner']['logo']) ? $settings['banner']['logo'] : NULL,
    '#description' => t('URL (https recommended) or base64 equivalent of an image to be used as a logo for the header of the cookie banner. Use a white SVG on transparent background for best result.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['banner']['brandTextColor'] = [
    '#title' => t('Brand text color'),
    '#type' => 'textfield',
    '#default_value' => isset($settings['banner']['brandTextColor']) ? $settings['banner']['brandTextColor'] : NULL,
    '#description' => t('(default "#000") Text color of the header of the modal/cookie banner.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['banner']['brandBackgroundColor'] = [
    '#title' => t('Brand background color'),
    '#type' => 'textfield',
    '#default_value' => isset($settings['banner']['brandBackgroundColor']) ? $settings['banner']['brandBackgroundColor'] : NULL,
    '#description' => t('(default "#fff") Background color of the header of the cookie banner.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['banner']['banner_colors'] = [
    '#markup' => '<h4>' . t('Banner colors') . '</h4>',
  ];
  
  $form['iubenda_integration_cookie_policy']['banner']['backgroundColor'] = [
    '#title' => t('Background color'),
    '#type' => 'textfield',
    '#default_value' => !empty($settings['banner']['backgroundColor']) ? $settings['banner']['backgroundColor'] : NULL,
    '#description' => t('(default "#000") The background color of the banner.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['banner']['textColor'] = [
    '#title' => t('Text color'),
    '#type' => 'textfield',
    '#default_value' => !empty($settings['banner']['textColor']) ? $settings['banner']['textColor'] : NULL,
    '#description' => t('(default "#fff") The color of the banner’s text.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['banner']['buttons'] = [
    '#markup' => '<h4>' . t('Buttons') . '</h4>',
  ];
  
  $form['iubenda_integration_cookie_policy']['banner']['acceptButtonDisplay'] = [
    '#title' => t('Accept button display'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['banner']['acceptButtonDisplay']) ? $settings['banner']['acceptButtonDisplay'] : FALSE,
    '#description' => t('Determines whether or not the “Accept” button is displayed.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['banner']['customizeButtonDisplay'] = [
    '#title' => t('Customize button display'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['banner']['customizeButtonDisplay']) ? $settings['banner']['customizeButtonDisplay'] : FALSE,
    '#description' => t('Determines whether or not the “Learn more and customize” button is displayed.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['banner']['rejectButtonDisplay'] = [
    '#title' => t('Reject button display'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['banner']['rejectButtonDisplay']) ? $settings['banner']['rejectButtonDisplay'] : FALSE,
    '#description' => t('Determines whether or not the “Reject” button is displayed. When true banner.closeButtonDisplay is forced to false.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['banner']['closeButtonDisplay'] = [
    '#title' => t('Close button display'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['banner']['closeButtonDisplay']) ? $settings['banner']['closeButtonDisplay'] : TRUE,
    '#description' => t('If set to false, the banner’s close button won’t be displayed.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['banner']['text'] = [
    '#markup' => '<h3>3.3 ' . t('Text') . '</h3>',
  ];
  
  $form['iubenda_integration_cookie_policy']['banner']['font_size'] = [
    '#markup' => '<h4>' . t('Font size') . '</h4>',
  ];
  
  $form['iubenda_integration_cookie_policy']['banner']['fontSize'] = [
    '#title' => t('Font size'),
    '#type' => 'textfield',
    '#default_value' => !empty($settings['banner']['fontSize']) ? $settings['banner']['fontSize'] : NULL,
    '#description' => t('The dimension of the banner’s text (including the closing button). If this option is active the possible values in the options banner.fontSizeCloseButton and banner.fontSizeBody will not be taken into account.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['banner']['fontSizeCloseButton'] = [
    '#title' => t('Font size close button'),
    '#type' => 'textfield',
    '#default_value' => !empty($settings['banner']['fontSizeCloseButton']) ? $settings['banner']['fontSizeCloseButton'] : NULL,
    '#description' => t('(default "20px") – The dimension of the banner’s closing button.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['banner']['fontSizeBody'] = [
    '#title' => t('Font size body'),
    '#type' => 'textfield',
    '#default_value' => !empty($settings['banner']['fontSizeBody']) ? $settings['banner']['fontSizeBody'] : NULL,
    '#description' => t('(default "14px") – The dimension of the banner’s text content.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['banner']['banner_copy'] = [
    '#markup' => '<h4>' . t('Banner copy') . '</h4>',
  ];
  
  $form['iubenda_integration_cookie_policy']['banner']['listPurposes'] = [
    '#title' => t('List purposes'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['banner']['listPurposes']) ? $settings['banner']['listPurposes'] : FALSE,
    '#description' => t('If true, it displays purposes in the first layer of the cookie banner (to be effective, perPurposeConsent must be set to true).'),
  ];
  
  $form['iubenda_integration_cookie_policy']['banner']['content'] = [
    '#title' => t('Content'),
    '#type' => 'textarea',
    '#rows' => 2,
    '#resizable' => TRUE,
    '#default_value' => !empty($settings['banner']['content']) ? $settings['banner']['content'] : NULL,
    '#description' => t('This is the textual content inside the cookie banner. For example, for the English version the default value is:<pre>
"Notice
We and selected partners use cookies or similar technologies as specified in the %{cookie_policy_link}."</pre>'),
    '#suffix' => t("Shortcodes available for banner.content:
<ul>
  <li>%{cookie_policy_link} is replaced with a link to cookiePolicyUrl and with the caption specified in banner.cookiePolicyLinkCaption</li>
  <li>%{advertising_preferences_link} is replaced with a link to the Transparency and Consent Framework widget</li>
  <li>%{vendor_list_link} is replaced with a link to the list of Transparency and Consent Framework vendors</li>
  <li>%{privacy_policy} is replaced with a link to the privacy policy (needed for CCPA)</li>
  <li>%{do_not_sell} is replaced with a link to opt out of CCPA selling</li>
</ul>"),
  ];
  
  $form['iubenda_integration_cookie_policy']['banner']['acceptButtonCaption'] = [
    '#title' => t('Accept button caption'),
    '#type' => 'textfield',
    '#default_value' => !empty($settings['banner']['acceptButtonCaption']) ? $settings['banner']['acceptButtonCaption'] : NULL,
    '#description' => t('(default “Accept”) – The text of the banner’s “Accept” button.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['banner']['customizeButtonCaption'] = [
    '#title' => t('Customize button caption'),
    '#type' => 'textfield',
    '#default_value' => !empty($settings['banner']['customizeButtonCaption']) ? $settings['banner']['customizeButtonCaption'] : NULL,
    '#description' => t('(default “Learn more and customize”) – The text of the banner’s “Learn more and customize” button.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['banner']['rejectButtonCaption'] = [
    '#title' => t('Reject button caption'),
    '#type' => 'textfield',
    '#default_value' => !empty($settings['banner']['rejectButtonCaption']) ? $settings['banner']['rejectButtonCaption'] : NULL,
    '#description' => t('(default “Reject”) – The text of the banner’s “Reject” button.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['banner']['advanced_settings'] = [
    '#markup' => '<h4>' . t('Advanced settings') . '</h4>',
  ];
  
  $form['iubenda_integration_cookie_policy']['banner']['zIndex'] = [
    '#title' => t('zIndex'),
    '#type' => 'textfield',
    '#default_value' => !empty($settings['banner']['zIndex']) ? $settings['banner']['zIndex'] : NULL,
    '#description' => t('This is the zIndex of the banner’s div. The default value is 99999998.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['banner']['html'] = [
    '#title' => t('HTML'),
    '#type' => 'textarea',
    '#rows' => 2,
    '#resizable' => TRUE,
    '#default_value' => !empty($settings['banner']['content']) ? $settings['banner']['content'] : NULL,
    '#description' => t('It is the default HTML of the banner, through this parameter it can be replaced with a customized one. Notes: some elements are in any case necessary for the proper functioning of the banner, in particular:
    <ul>
      <li>div.iubenda-cs-content (the main container)</li>
      <li>a.iubenda-cs-cookie-policy-lnk (the href link set to link to the cookie policy, ie https://www.iubenda.com/privacy-policy/123456/cookie-policy?an=no&s_ck=false)</li>
    </ul>'),
    '#suffix' => t("Shortcodes available for banner.content:
    <ul>
      <li>%{banner_content} is replaced with the value specified in banner.content (or the default banner content). Please note that %{banner_content} is mandatory in case of TCF v2 (unless we’ve approved your custom text).</li>
    </ul>"),
  ];
  
  $form['iubenda_integration_cookie_policy']['banner']['innerHtmlCloseBtn'] = [
    '#title' => t('Close button - inner HTML'),
    '#type' => 'textfield',
    '#default_value' => !empty($settings['banner']['innerHtmlCloseBtn']) ? $settings['banner']['innerHtmlCloseBtn'] : NULL,
    '#description' => t('(default "x") The text of the banner’s close button.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['banner']['slideDown'] = [
    '#title' => t('Slide down'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['banner']['slideDown']) ? $settings['banner']['slideDown'] : TRUE,
    '#description' => t('Set to false to remove the initial banner animation'),
  ];
  
  $form['iubenda_integration_cookie_policy']['banner']['prependOnBody'] = [
    '#title' => t('Prepend on Body'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['banner']['prependOnBody']) ? $settings['banner']['prependOnBody'] : FALSE,
    '#description' => t('If this parameter is set on true, the HTML code of the banner is injected into the site as the first element of the BODY. By default prependOnBody is set to false and the banner is placed as the last element of the BODY.'),
    '#suffix' => t('You must set prependOnBody on true when you want, for example, to place the banner above the header. In this way, the banner will be the first element on the page, and in order to display it on top of the header, simply apply a “padding-top” to the next item: <code>#iubenda-cs-banner + * { padding-top: 180px; }</code>'),
  ];
  
  $form['iubenda_integration_cookie_policy']['banner']['consentOnScrollDelay'] = [
    '#title' => t('Consent on scroll delay'),
    '#type' => 'textfield',
    '#default_value' => !empty($settings['banner']['consentOnScrollDelay']) ? $settings['banner']['consentOnScrollDelay'] : 500,
    '#description' => t('(default 500) – The maximum time between the activations of snippets tagged with the class _iub_cs_activate-inline (the snippet tagged in this way are activated sequentially). By decreasing this value you will reduce the total time of activation. Caution: the default value is set in order for the snippets to work properly; reducing it may prevent the successful activation of some snippet. It is highly recommended to check the activation of the snippet shown on your page if this setting is changed.)'),
  ];
  
  $form['iubenda_integration_cookie_policy']['banner']['cookiePolicyLinkCaption'] = [
    '#title' => t('Cookie Policy link caption'),
    '#type' => 'textfield',
    '#default_value' => !empty($settings['banner']['cookiePolicyLinkCaption']) ? $settings['banner']['cookiePolicyLinkCaption'] : NULL,
    '#description' => t('Anchor text of the link to the cookie policy (the default value is "cookie policy").'),
  ];
  
  $form['iubenda_integration_cookie_policy']['banner']['acceptButtonColor'] = [
    '#title' => t('Accept button color'),
    '#type' => 'textfield',
    '#default_value' => !empty($settings['banner']['acceptButtonColor']) ? $settings['banner']['acceptButtonColor'] : NULL,
    '#description' => t('(default "#0073ce") Background color of the “Accept” button.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['banner']['acceptButtonCaptionColor'] = [
    '#title' => t('Accept button caption color'),
    '#type' => 'textfield',
    '#default_value' => !empty($settings['banner']['acceptButtonCaptionColor']) ? $settings['banner']['acceptButtonCaptionColor'] : NULL,
    '#description' => t('(default "#fff") Text color of the “Accept” button'),
  ];
  
  $form['iubenda_integration_cookie_policy']['banner']['customizeButtonColor'] = [
    '#title' => t('Customize button color'),
    '#type' => 'textfield',
    '#default_value' => !empty($settings['banner']['customizeButtonColor']) ? $settings['banner']['customizeButtonColor'] : NULL,
    '#description' => t('(dark theme default “#212121”, light theme default “#dadada”) Background color of the “Learn more and customize” button.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['banner']['customizeButtonCaptionColor'] = [
    '#title' => t('Customize button caption color'),
    '#type' => 'textfield',
    '#default_value' => !empty($settings['banner']['customizeButtonCaptionColor']) ? $settings['banner']['customizeButtonCaptionColor'] : NULL,
    '#description' => t('(dark theme default “#fff”, light theme default “#4d4d4d”) Text color of the “Learn more and customize” button.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['banner']['rejectButtonColor'] = [
    '#title' => t('Reject button color'),
    '#type' => 'textfield',
    '#default_value' => !empty($settings['banner']['rejectButtonColor']) ? $settings['banner']['rejectButtonColor'] : NULL,
    '#description' => t('(default "#0073ce") Background color of the “Reject” button.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['banner']['rejectButtonCaptionColor'] = [
    '#title' => t('Reject button caption color'),
    '#type' => 'textfield',
    '#default_value' => !empty($settings['banner']['rejectButtonCaptionColor']) ? $settings['banner']['rejectButtonCaptionColor'] : NULL,
    '#description' => t('(default "#fff") Text color of the “Reject” button.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['footer'] = [
    '#title' => t('Footer'),
    '#type' => 'fieldset',
    '#tree' => TRUE,
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  ];
  
  $form['iubenda_integration_cookie_policy']['footer']['btnCaption'] = [
    '#title' => t('Button caption'),
    '#type' => 'textfield',
    '#default_value' => !empty($settings['footer']['btnCaption']) ? $settings['footer']['btnCaption'] : NULL,
    '#description' => t('Text of the button (located at the bottom of the “Tracking preferences” window, see per-category consent) used to save the consent preferences. The default value is “Save and continue”.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['consent_widget'] = [
    '#markup' => '<h3>3.4 ' . t('Consent widget') . '</h3>',
  ];
  
  $form['iubenda_integration_cookie_policy']['floatingPreferencesButtonDisplay'] = [
    '#title' => t('Floating preferences button display'),
    '#type' => 'select',
    '#options' => [
      '' => t('Disabled'),
      'top-left' => t('Top left'),
      'top-right' => t('Top right'),
      'bottom-left' => t('Bottom left'),
      'bottom-right' => t('Bottom right'),
      'anchored-center-left' => t('Anchored center left'),
      'anchored-center-right' => t('Anchored center right'),
      'anchored-top-left' => t('Anchored top left'),
      'anchored-top-right' => t('Anchored top right'),
      'anchored-bottom-left' => t('Anchored bottom left'),
      'anchored-bottom-right' => t('Anchored bottom right'),
    ],
    '#default_value' => isset($settings['floatingPreferencesButtonDisplay']) ? $settings['floatingPreferencesButtonDisplay'] : 0,
    '#description' => t('It defines the position of the privacy widget (a feature that allows your users to access and edit tracking preferences at any time after setting their initial preferences). '),
  ];
  
  $form['iubenda_integration_cookie_policy']['consent_widget_format'] = [
    '#markup' => '<h4>' . t('Format') . '</h4>',
  ];
  
  $form['iubenda_integration_cookie_policy']['floatingPreferencesButtonCaption'] = [
    '#title' => t('Floating preferences button caption'),
    '#type' => 'textfield',
    '#default_value' => !empty($settings['floatingPreferencesButtonCaption']) ? $settings['floatingPreferencesButtonCaption'] : '',
    '#description' => t('Text of the privacy widget button.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['floatingPreferencesButtonIcon'] = [
    '#title' => t('Floating preferences button icon'),
    '#type' => 'checkbox',
    '#default_value' => !empty($settings['floatingPreferencesButtonIcon']) ? $settings['floatingPreferencesButtonIcon'] : TRUE,
    '#description' => t('Icon of the privacy widget button.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['floatingPreferencesButtonHover'] = [
    '#title' => t('Floating preferences button hover'),
    '#type' => 'checkbox',
    '#default_value' => !empty($settings['floatingPreferencesButtonHover']) ? $settings['floatingPreferencesButtonHover'] : FALSE,
    '#description' => t('Shows the privacy widget text on hover.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['floatingPreferencesButtonRound'] = [
    '#title' => t('Floating preferences button round'),
    '#type' => 'checkbox',
    '#default_value' => !empty($settings['floatingPreferencesButtonRound']) ? $settings['floatingPreferencesButtonRound'] : FALSE,
    '#description' => t('Adds the iubenda-tp-circle attribute to the privacy widget button.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['consent_widget_colors'] = [
    '#markup' => '<h4>' . t('Colors') . '</h4>',
  ];
  
  $form['iubenda_integration_cookie_policy']['floatingPreferencesButtonColor'] = [
    '#title' => t('Floating preferences button color'),
    '#type' => 'textfield',
    '#default_value' => !empty($settings['floatingPreferencesButtonColor']) ? $settings['floatingPreferencesButtonColor'] : NULL,
    '#description' => t('(default “#fff”) – Background color of the privacy widget button.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['floatingPreferencesButtonCaptionColor'] = [
    '#title' => t('Floating preferences button caption color'),
    '#type' => 'textfield',
    '#default_value' => !empty($settings['floatingPreferencesButtonCaptionColor']) ? $settings['floatingPreferencesButtonCaptionColor'] : NULL,
    '#description' => t('(default “#000”) – Text color of the privacy widget button.)'),
  ];
  
  $form['iubenda_integration_cookie_policy']['privacy_and_cookie_policy'] = [
    '#markup' => '<h2>4 ' . t('Privacy and cookie policy') . '</h2>',
  ];
  
  $form['iubenda_integration_cookie_policy']['privacyPolicyUrl'] = [
    '#title' => t('Privacy Policy URL'),
    '#type' => 'textfield',
    '#default_value' => !empty($settings['privacyPolicyUrl']) ? $settings['privacyPolicyUrl'] : NULL,
    '#description' => t('Allows you to customize the privacy policy link.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['cookiePolicyUrl'] = [
    '#title' => t('Cookie Policy URL'),
    '#type' => 'textfield',
    '#default_value' => !empty($settings['cookiePolicyUrl']) ? $settings['cookiePolicyUrl'] : NULL,
    '#description' => t('The URL of your cookie policy, available in your dashboard, or from any page that hosts the policy.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['cookiePolicyInOtherWindow'] = [
    '#title' => t('Cookie Policy in other window'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['cookiePolicyInOtherWindow']) ? $settings['cookiePolicyInOtherWindow'] : FALSE,
    '#description' => t('If you set this parameter to true the privacy policy and the cookie policy will open in another window instead of the iubenda modal window.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['advanced_settings'] = [
    '#markup' => '<h2>5 ' . t('Advanced settings') . '</h2>',
  ];
  
  $form['iubenda_integration_cookie_policy']['advanced_settings'] = [
    '#markup' => '<h3>5.2 ' . t('Consent collection settings') . '</h3>',
  ];
  
  $form['iubenda_integration_cookie_policy']['reloadOnConsent'] = [
    '#title' => t('Reload on consent'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['reloadOnConsent']) ? $settings['reloadOnConsent'] : FALSE,
    '#description' => t('You can set this parameter to true if you want the page to be reloaded after the collection of the consent.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['askConsentAtCookiePolicyUpdate'] = [
    '#title' => t('Ask consent at Cookie Policy update'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['askConsentAtCookiePolicyUpdate']) ? $settings['askConsentAtCookiePolicyUpdate'] : FALSE,
    '#description' => t('You can set this parameter to true if you want to request new consent when the Cookie Policy is updated.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['enableRemoteConsent'] = [
    '#title' => t('Enable remote consent'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['enableRemoteConsent']) ? $settings['enableRemoteConsent'] : FALSE,
    '#description' => t('You can set this parameter to true to enable a cross-site registration of the consent (it can be useful when the script is implemented in more than one websites of the same network). In particular, if you set this parameter to true, our solution creates a technical cookie on iubenda.com (domain) which is used when the cookie on the local domain is not found.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['priorConsent'] = [
    '#title' => t('Prior consent'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['priorConsent']) ? $settings['priorConsent'] : TRUE,
    '#description' => t('Enables the blocking of scripts and their reactivation only after having collected user consent. If false, the blocked scripts are always reactivated regardless of whether or not consent has been provided (useful for testing purposes, or when you’re working on your project locally and don’t want pageviews to be counted).'),
    '#suffix' => t('We strongly advise against setting "priorConsent":false if you need to comply with EU legislation. Please note that if the prior blocking setting has been disabled server side (via the checkbox on the flow page), this parameter will be ineffective whether it’s set to true or false.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['invalidateConsentWithoutLog'] = [
    '#title' => t('Invalidate Consent without log'),
    '#type' => 'textfield',
    '#default_value' => !empty($settings['invalidateConsentWithoutLog']) ? $settings['invalidateConsentWithoutLog'] : NULL,
    '#description' => t('If a date is set (format: “yyyy-mm-dd”) when consent collected prior to this date is not found within the Cookie Preference Log a new consent will be requested(e.g. invalidateConsentWithoutLog: "2022-01-10“)'),
  ];
  
  $form['iubenda_integration_cookie_policy']['development'] = [
    '#markup' => '<h3>5.3 ' . t('Development') . '</h3>',
  ];
  
  $form['iubenda_integration_cookie_policy']['inlineDelay'] = [
    '#title' => t('Inline delay'),
    '#type' => 'textfield',
    '#default_value' => !empty($settings['inlineDelay']) ? $settings['inlineDelay'] : 500,
    '#description' => t('(default 500) – The maximum time between the activations of snippets tagged with the class _iub_cs_activate-inline (the snippet tagged in this way are activated sequentially). By decreasing this value you will reduce the total time of activation. Caution: the default value is set in order for the snippets to work properly; reducing it may prevent the successful activation of some snippet. It is highly recommended to check the activation of the snippet shown on your page if this setting is changed.)'),
  ];
  
  $form['iubenda_integration_cookie_policy']['rebuildIframe'] = [
    '#title' => t('Rebuild iframe'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['rebuildIframe']) ? $settings['rebuildIframe'] : TRUE,
    '#description' => t('Once the user’s consent has been recorded, the default behavior of the Cookie Solution is to fully regenerate (or reintegrate) the iframes previously modified. By setting this parameter to false, the iframes previously blocked are restored after the collection of consent.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['callback'] = [
    '#title' => t('Callbacks'),
    '#type' => 'fieldset',
  ];
  
  $form['iubenda_integration_cookie_policy']['callback']['help'] = [
    '#markup' => t('You can define your custom callbacks by using javascript from within your module in the following way:'),
    '#suffix' => '<pre>
(function ($) {
  Drupal.iubCallbacks = Drupal.iubCallbacks || {};
  Drupal.iubCallbacks.onReady = function (e) {
    console.log("do something crazy");
  }
})(jQuery);</pre><p><a target="_blank" href="https://www.iubenda.com/en/help/1205-how-to-configure-your-cookie-solution-advanced-guide#development">Iubenda Callbacks</a></p>',
  ];
  
  $form['iubenda_integration_cookie_policy']['developers'] = [
    '#title' => t('Debugging'),
    '#type' => 'fieldset',
  ];
  
  $form['iubenda_integration_cookie_policy']['developers']['skipSaveConsent'] = [
    '#title' => t('Skip save consent'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['developers']['skipSaveConsent']) ? $settings['developers']['skipSaveConsent'] : FALSE,
    '#description' => t('By setting this parameter to true, the consent is not saved in a preference cookie.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['developers']['logLevel'] = [
    '#title' => t('Log level'),
    '#type' => 'select',
    '#options' => [
      '' => t('- Select -'),
      'debug' => t('Debug'),
      'info' => t('info'),
      'warn' => t('warn'),
      'error' => t('error'),
      'fatal' => t('fatal'),
    ],
    '#default_value' => !empty($settings['developers']['logLevel']) ? $settings['developers']['logLevel'] : NULL,
  ];
  
  $form['iubenda_integration_cookie_policy']['developers']['logViaAlert'] = [
    '#title' => t('Log via alert'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['developers']['logViaAlert']) ? $settings['developers']['logViaAlert'] : FALSE,
    '#description' => t('By setting this parameter to true, the logging is shown via alert.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['preferenceCookie'] = [
    '#title' => t('Preference Cookie'),
    '#type' => 'fieldset',
    '#tree' => TRUE,
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  ];
  
  $form['iubenda_integration_cookie_policy']['preferenceCookie']['expireAfter'] = [
    '#title' => t('Expire after'),
    '#type' => 'textfield',
    '#default_value' => !empty($settings['preferenceCookie']['expireAfter']) ? $settings['preferenceCookie']['expireAfter'] : NULL,
    '#description' => t('(default 365) – It represents the number of days of validity of the consent given by the user on a given web site. Note: this value is updated at each subsequent visit by the user.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['ccpaCookie'] = [
    '#title' => t('CCPA Cookie'),
    '#type' => 'fieldset',
    '#tree' => TRUE,
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  ];
  
  $form['iubenda_integration_cookie_policy']['ccpaCookie']['expireAfter'] = [
    '#title' => t('Expire after'),
    '#type' => 'textfield',
    '#default_value' => !empty($settings['ccpaCookie']['expireAfter']) ? $settings['ccpaCookie']['expireAfter'] : NULL,
    '#description' => t('(default 365) – Number of days of validity.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['consent_domain'] = [
    '#markup' => '<h4>' . t('Local consent domain and path') . '</h4>',
  ];
  
  $form['iubenda_integration_cookie_policy']['localConsentDomain'] = [
    '#title' => t('Load consent domain'),
    '#type' => 'textfield',
    '#default_value' => !empty($settings['reloadOnConsent']) ? $settings['reloadOnConsent'] : NULL,
    '#description' => t('The domain on which you want the consent given by the user saved. If this parameter isn’t given, the consent gets saved by default in a cookie for the domain on a second level of the current page (for example: visiting www.example.com, the consent gets saved in a cookie on the on the domain .example.com). In the case in which the default behavior isn’t suitable, for example if the site were www.paesaggiurbani.italia.it and the consent needs to be saved for paesaggiurbani.italia.it, you need to fill that parameter with ‘paesaggiurbani.italia.it’.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['localConsentPath'] = [
    '#title' => t('Load consent path'),
    '#type' => 'textfield',
    '#default_value' => !empty($settings['localConsentPath']) ? $settings['localConsentPath'] : '/',
    '#description' => t('The path at which you’ll want, on the local domain, the consent by the user saved. By default, the consent given by the user gets saved on the local domain in a cookie on the path ‘/’. In this way, the cookie is available at whichever page of the domain that a user accesses. If on the other hand one would like to not make the preference cookie set for www.example.com/user1 available on www.example.com/user2, and vice versa, you’ll need to set this parameter to the calue ‘/user1’ in the first case and the value to ‘/user2’ in the second.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['further_parameters'] = [
    '#markup' => '<h4>' . t('Further parameters') . '</h4>',
  ];
  
  $form['iubenda_integration_cookie_policy']['whitelabel'] = [
    '#title' => t('White label'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['whitelabel']) ? $settings['whitelabel'] : TRUE,
    '#description' => t('Set this parameter to false to show the iubenda branding on the second layer.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['invalidateConsentBefore'] = [
    '#title' => t('Max Cookie size'),
    '#type' => 'textfield',
    '#default_value' => isset($settings['invalidateConsentBefore']) ? $settings['invalidateConsentBefore'] : NULL,
    '#description' => t('(“YYYY-MM-DD”, milliseconds from epoch, default null) – All consents collected prior to this date will be invalidated. Consents collected on this date and in the future will not be invalidated.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['maxCookieSize'] = [
    '#title' => t('Max Cookie size'),
    '#type' => 'textfield',
    '#default_value' => isset($settings['maxCookieSize']) ? $settings['maxCookieSize'] : 4096,
    '#description' => t('To avoid browsers reject cookies longer than 4096 characters, the Cookie Solution allows to split cookies in multiple chunks. With maxCookieSize you can configure the maximum length of every chunk (see also maxCookieChunks).'),
  ];
  
  $form['iubenda_integration_cookie_policy']['maxCookieChunks'] = [
    '#title' => t('Max Cookie chunks'),
    '#type' => 'textfield',
    '#default_value' => isset($settings['maxCookieChunks']) ? $settings['maxCookieChunks'] : 5,
    '#description' => t('With this parameter you can configure the maximum number of chunks into which cookies can be split (see also maxCookieSize).'),
    '#suffix' => t('Note: if the cookie to be saved is longer than maxCookieSize * maxCookieChunks (20480 chars with default values), then the cookie is not saved.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['timeoutLoadConfiguration'] = [
    '#title' => t('Timeout load configuration'),
    '#type' => 'textfield',
    '#default_value' => isset($settings['startOnDomReady']) ? $settings['startOnDomReady'] : 30000,
    '#description' => t('The amount of time to wait for the remote configuration before stating that a timeout occurred. In case of a slow network, by increasing this value, you’ll make sure that the Cookie Solution gets the needed resources on time.'),
  ];
  
  $form['iubenda_integration_cookie_policy']['startOnDomReady'] = [
    '#title' => t('Start on DOM ready'),
    '#type' => 'checkbox',
    '#default_value' => isset($settings['startOnDomReady']) ? $settings['startOnDomReady'] : TRUE,
    '#description' => t('If true banner rendering and/or activation of blocked snippets will be performed as soon as the document status is ‘loaded’ (i.e. when the DOM reaches the ‘loaded’ status). If the option is set to false, then the Cookie Solution will start when the page has been fully loaded (i.e. when the DOM status is ‘completed’ and all resources included in the page have been loaded).'),
  ];
  
  $form['#attached']['css'][] = drupal_get_path('module', 'iubenda_integration') . '/css/iubenda_integration.admin.css';
  
  return system_settings_form($form);
}

/**
 * Ajax callback.
 *
 * @see iubenda_integration_cookie_policy_settings_form()
 */
function iubenda_integration_cookie_policy_ajax_callback($form, &$form_state) {
  return $form;
}
